==> aime_0.59.orig.tar.gz: aime-0.59.orig/include/spec_func_table.h <==
#ifndef _SPEC_FUNC_TABLE_H
#define _SPEC_FUNC_TABLE_H

#include "special_func.h"
#include "config.h"

struct spec_func_data {
   char      *functname;
   Spec_Func specfunctptr;
};


spec_func_data specfuncts[] = {
        {"send_actor", send_actor}, 
        {"send_room", send_all_room},
        {"send_room_except", send_all_room_except},
        {"send_room_except_dual", send_room_except_dual},
        {"send_obj_room", send_obj_room},
        {"send_all", send_all},
        {"send_all_except", send_all_except},
        {"send_to", send_to},
        {"send_holder", send_holder},
        {"tell_ind", tell_ind},
        {"goto", goto_spec},
        {"goto_if_eq", goto_if_eq},
        {"goto_if_neq", goto_if_neq},
        {"goto_if_less", goto_if_less},
        {"return_invalid_criteria", ret_inv_crit},
        {"force_termination", force_termination},
        {"force_failure", force_failure},
        {"force_success", force_success},
        {"set", set},
        {"get", get},
        {"destroy_this_obj", destroy_this_obj},
        {"get_parent_name", get_parent_name},
        {"is_individual", is_individual},
        {"clone_object", clone_object},
        {"add_status", spec_add_status},
        {"remove_status", remove_status},
        {"has_status", has_status},
        {"move_object", move_object},
        {"object_exists", object_exists},
        {"attach_special", attach_special},
        {"detach_special", detach_special},
        {"is_itemflag_set", is_itemflag_set},
        {"set_itemflag", set_itemflag},
        {"clr_itemflag", clr_itemflag},
        {"ambush_individual", ambush_individual},
        {"damage_individual", damage_individual},
        {"fight_player", fight_player},
        {"is_indflag_set", is_indflag_set},
        {"set_indflag", set_indflag},
        {"clr_indflag", clr_indflag},
        {"ind_holds", ind_holds},
        {"trans_player", trans_player},
        {"add_ability", add_ability},
        {"remove_ability", remove_ability},
        {"has_ability", has_ability},
        {"boot_off", boot_off},
        {"award_quest", award_quest},
        {"advance_experience", advance_experience},
        {"push_prompt", push_prompt},
        {"pop_prompt", pop_prompt},
        {"start_busy", start_busy},
        {"end_busy", end_busy},
        {"decrement_number_of", decrement_number_of},
        {"increment_number_of", increment_number_of},
        {"get_number_of", get_number_of},
        {"set_door_state", set_door_state},
        {"get_door_state", get_door_state},
        {"get_loc_by_dir", get_loc_by_dir},
        {"display_loc", display_loc},
        {"decrement_counter", decrement_counter},
        {"increment_counter", increment_counter},
        {"get_counter", get_counter},
        {"set_counter", set_counter},
        {"set_param", set_param},
        {"set_store_int", set_store_int},
        {"get_store_int", get_store_int},
        {"get_target_str", get_target_str},
        {"increment_number", increment_number},
        {"decrement_number", decrement_number},
        {"get_random", get_random},
        {"select_rand_param", select_rand_param},
        {"is_string_eq", is_string_eq},
        {"test_for_success", test_for_success},
        {"assign", assign},
        {"exit_tutorial", exit_tutorial},
	{"apply_special_loc", apply_special_loc},
        {"damage_all_room", damage_all_room},
        {"light_all_room", light_all_room},
	{"display_objects", display_objects},  
	{NULL, NULL}};


#endif

==> aime_0.60.3.orig.tar.gz: aime-0.60.3.orig/include/spec_func_table.h <==
#ifndef _SPEC_FUNC_TABLE_H
#define _SPEC_FUNC_TABLE_H

#include "special_func.h"
#include "config.h"

struct spec_func_data {
   char      *functname;
   Spec_Func specfunctptr;
};


spec_func_data specfuncts[] = {
        {"send_actor", send_actor}, 
        {"send_room", send_all_room},
        {"send_room_except", send_all_room_except},
        {"send_room_except_dual", send_room_except_dual},
        {"send_obj_room", send_obj_room},
        {"send_all", send_all},
        {"send_all_except", send_all_except},
        {"send_to", send_to},
        {"send_to_room", send_to_room},
        {"send_holder", send_holder},
        {"tell_ind", tell_ind},
        {"goto", goto_spec},
        {"goto_if_eq", goto_if_eq},
        {"goto_if_neq", goto_if_neq},
        {"goto_if_less", goto_if_less},
        {"return_invalid_criteria", ret_inv_crit},
        {"force_termination", force_termination},
        {"force_failure", force_failure},
        {"force_success", force_success},
        {"set", set},
        {"get", get},
        {"destroy_this_obj", destroy_this_obj},
        {"get_parent_name", get_parent_name},
        {"is_individual", is_individual},
        {"clone_object", clone_object},
        {"add_status", spec_add_status},
        {"remove_status", remove_status},
        {"has_status", has_status},
        {"move_object", move_object},
        {"object_exists", object_exists},
        {"attach_special", attach_special},
        {"detach_special", detach_special},
        {"is_itemflag_set", is_itemflag_set},
        {"set_itemflag", set_itemflag},
        {"clr_itemflag", clr_itemflag},
        {"ambush_individual", ambush_individual},
        {"damage_individual", damage_individual},
        {"fight_player", fight_player},
        {"is_indflag_set", is_indflag_set},
        {"set_indflag", set_indflag},
        {"clr_indflag", clr_indflag},
        {"ind_holds", ind_holds},
        {"ind_wears", ind_wears},
        {"is_a_corpse", is_a_corpse},
	{"set_brief", set_brief},
	{"set_examine", set_examine},
        {"trans_actor", trans_actor},
        {"add_ability", add_ability},
        {"remove_ability", remove_ability},
        {"has_ability", has_ability},
        {"boot_off", boot_off},
        {"award_quest", award_quest},
        {"advance_experience", advance_experience},
        {"push_prompt", push_prompt},
        {"pop_prompt", pop_prompt},
        {"start_busy", start_busy},
        {"end_busy", end_busy},
        {"decrement_number_of", decrement_number_of},
        {"increment_number_of", increment_number_of},
        {"get_number_of", get_number_of},
        {"set_door_state", set_door_state},
        {"get_door_state", get_door_state},
        {"get_loc_by_dir", get_loc_by_dir},
        {"display_loc", display_loc},
        {"decrement_counter", decrement_counter},
        {"increment_counter", increment_counter},
        {"get_counter", get_counter},
        {"set_counter", set_counter},
        {"set_param", set_param},
        {"set_store_int", set_store_int},
        {"get_store_int", get_store_int},
        {"get_target_str", get_target_str},
        {"increment_number", increment_number},
        {"decrement_number", decrement_number},
        {"get_random", get_random},
        {"select_rand_param", select_rand_param},
        {"is_string_eq", is_string_eq},
        {"test_for_success", test_for_success},
        {"assign", assign},
        {"exit_tutorial", exit_tutorial},
	{"apply_special_loc", apply_special_loc},
        {"damage_all_room", damage_all_room},
        {"light_all_room", light_all_room},
	{"display_objects", display_objects},  
	{NULL, NULL}};


#endif
